# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMathematicalMorphologyPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkGrayscaleGeodesicErodeImageFilterPython
else:
    import _itkGrayscaleGeodesicErodeImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkImageRegionPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkGrayscaleGeodesicErodeImageFilterIF2IF2_New():
    return itkGrayscaleGeodesicErodeImageFilterIF2IF2.New()

class itkGrayscaleGeodesicErodeImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkGrayscaleGeodesicErodeImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleGeodesicErodeImageFilterIF2IF2_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleGeodesicErodeImageFilterIF2IF2_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_Clone(self)

    def SetMarkerImage(self, arg0):
        r"""
        SetMarkerImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF2 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_SetMarkerImage(self, arg0)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageF2"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_GetMarkerImage(self)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF2 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageF2"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_GetMaskImage(self)

    def SetRunOneIteration(self, _arg):
        r"""
        SetRunOneIteration(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_SetRunOneIteration(self, _arg)

    def GetRunOneIteration(self):
        r"""GetRunOneIteration(self) -> bool"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_GetRunOneIteration(self)

    def RunOneIterationOn(self):
        r"""RunOneIterationOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_RunOneIterationOn(self)

    def RunOneIterationOff(self):
        r"""RunOneIterationOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_RunOneIterationOff(self)

    def GetNumberOfIterationsUsed(self):
        r"""GetNumberOfIterationsUsed(self) -> unsigned long"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_GetNumberOfIterationsUsed(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_FullyConnectedOff(self)
    SameDimensionCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_SameDimensionCheck
    
    InputComparableCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_InputComparableCheck
    
    InputConvertibleToOutputCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_InputConvertibleToOutputCheck
    
    __swig_destroy__ = _itkGrayscaleGeodesicErodeImageFilterPython.delete_itkGrayscaleGeodesicErodeImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleGeodesicErodeImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleGeodesicErodeImageFilterIF2IF2

        Create a new object of the class itkGrayscaleGeodesicErodeImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleGeodesicErodeImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleGeodesicErodeImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleGeodesicErodeImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleGeodesicErodeImageFilterIF2IF2 in _itkGrayscaleGeodesicErodeImageFilterPython:
_itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF2IF2_swigregister(itkGrayscaleGeodesicErodeImageFilterIF2IF2)

def itkGrayscaleGeodesicErodeImageFilterIF3IF3_New():
    return itkGrayscaleGeodesicErodeImageFilterIF3IF3.New()

class itkGrayscaleGeodesicErodeImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkGrayscaleGeodesicErodeImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleGeodesicErodeImageFilterIF3IF3_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleGeodesicErodeImageFilterIF3IF3_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_Clone(self)

    def SetMarkerImage(self, arg0):
        r"""
        SetMarkerImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF3 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_SetMarkerImage(self, arg0)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageF3"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_GetMarkerImage(self)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF3 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageF3"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_GetMaskImage(self)

    def SetRunOneIteration(self, _arg):
        r"""
        SetRunOneIteration(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_SetRunOneIteration(self, _arg)

    def GetRunOneIteration(self):
        r"""GetRunOneIteration(self) -> bool"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_GetRunOneIteration(self)

    def RunOneIterationOn(self):
        r"""RunOneIterationOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_RunOneIterationOn(self)

    def RunOneIterationOff(self):
        r"""RunOneIterationOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_RunOneIterationOff(self)

    def GetNumberOfIterationsUsed(self):
        r"""GetNumberOfIterationsUsed(self) -> unsigned long"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_GetNumberOfIterationsUsed(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_FullyConnectedOff(self)
    SameDimensionCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_SameDimensionCheck
    
    InputComparableCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_InputComparableCheck
    
    InputConvertibleToOutputCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_InputConvertibleToOutputCheck
    
    __swig_destroy__ = _itkGrayscaleGeodesicErodeImageFilterPython.delete_itkGrayscaleGeodesicErodeImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleGeodesicErodeImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleGeodesicErodeImageFilterIF3IF3

        Create a new object of the class itkGrayscaleGeodesicErodeImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleGeodesicErodeImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleGeodesicErodeImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleGeodesicErodeImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleGeodesicErodeImageFilterIF3IF3 in _itkGrayscaleGeodesicErodeImageFilterPython:
_itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIF3IF3_swigregister(itkGrayscaleGeodesicErodeImageFilterIF3IF3)

def itkGrayscaleGeodesicErodeImageFilterISS2ISS2_New():
    return itkGrayscaleGeodesicErodeImageFilterISS2ISS2.New()

class itkGrayscaleGeodesicErodeImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkGrayscaleGeodesicErodeImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleGeodesicErodeImageFilterISS2ISS2_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleGeodesicErodeImageFilterISS2ISS2_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_Clone(self)

    def SetMarkerImage(self, arg0):
        r"""
        SetMarkerImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS2 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_SetMarkerImage(self, arg0)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS2"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_GetMarkerImage(self)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS2 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_GetMaskImage(self)

    def SetRunOneIteration(self, _arg):
        r"""
        SetRunOneIteration(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_SetRunOneIteration(self, _arg)

    def GetRunOneIteration(self):
        r"""GetRunOneIteration(self) -> bool"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_GetRunOneIteration(self)

    def RunOneIterationOn(self):
        r"""RunOneIterationOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_RunOneIterationOn(self)

    def RunOneIterationOff(self):
        r"""RunOneIterationOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_RunOneIterationOff(self)

    def GetNumberOfIterationsUsed(self):
        r"""GetNumberOfIterationsUsed(self) -> unsigned long"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_GetNumberOfIterationsUsed(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_FullyConnectedOff(self)
    SameDimensionCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_SameDimensionCheck
    
    InputComparableCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_InputComparableCheck
    
    InputConvertibleToOutputCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_InputConvertibleToOutputCheck
    
    __swig_destroy__ = _itkGrayscaleGeodesicErodeImageFilterPython.delete_itkGrayscaleGeodesicErodeImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleGeodesicErodeImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleGeodesicErodeImageFilterISS2ISS2

        Create a new object of the class itkGrayscaleGeodesicErodeImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleGeodesicErodeImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleGeodesicErodeImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleGeodesicErodeImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleGeodesicErodeImageFilterISS2ISS2 in _itkGrayscaleGeodesicErodeImageFilterPython:
_itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS2ISS2_swigregister(itkGrayscaleGeodesicErodeImageFilterISS2ISS2)

def itkGrayscaleGeodesicErodeImageFilterISS3ISS3_New():
    return itkGrayscaleGeodesicErodeImageFilterISS3ISS3.New()

class itkGrayscaleGeodesicErodeImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkGrayscaleGeodesicErodeImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleGeodesicErodeImageFilterISS3ISS3_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleGeodesicErodeImageFilterISS3ISS3_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_Clone(self)

    def SetMarkerImage(self, arg0):
        r"""
        SetMarkerImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS3 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_SetMarkerImage(self, arg0)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS3"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_GetMarkerImage(self)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS3 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_GetMaskImage(self)

    def SetRunOneIteration(self, _arg):
        r"""
        SetRunOneIteration(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_SetRunOneIteration(self, _arg)

    def GetRunOneIteration(self):
        r"""GetRunOneIteration(self) -> bool"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_GetRunOneIteration(self)

    def RunOneIterationOn(self):
        r"""RunOneIterationOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_RunOneIterationOn(self)

    def RunOneIterationOff(self):
        r"""RunOneIterationOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_RunOneIterationOff(self)

    def GetNumberOfIterationsUsed(self):
        r"""GetNumberOfIterationsUsed(self) -> unsigned long"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_GetNumberOfIterationsUsed(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_FullyConnectedOff(self)
    SameDimensionCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_SameDimensionCheck
    
    InputComparableCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_InputComparableCheck
    
    InputConvertibleToOutputCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_InputConvertibleToOutputCheck
    
    __swig_destroy__ = _itkGrayscaleGeodesicErodeImageFilterPython.delete_itkGrayscaleGeodesicErodeImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleGeodesicErodeImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleGeodesicErodeImageFilterISS3ISS3

        Create a new object of the class itkGrayscaleGeodesicErodeImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleGeodesicErodeImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleGeodesicErodeImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleGeodesicErodeImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleGeodesicErodeImageFilterISS3ISS3 in _itkGrayscaleGeodesicErodeImageFilterPython:
_itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterISS3ISS3_swigregister(itkGrayscaleGeodesicErodeImageFilterISS3ISS3)

def itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_New():
    return itkGrayscaleGeodesicErodeImageFilterIUC2IUC2.New()

class itkGrayscaleGeodesicErodeImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkGrayscaleGeodesicErodeImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_Clone(self)

    def SetMarkerImage(self, arg0):
        r"""
        SetMarkerImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_SetMarkerImage(self, arg0)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC2"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_GetMarkerImage(self)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_GetMaskImage(self)

    def SetRunOneIteration(self, _arg):
        r"""
        SetRunOneIteration(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_SetRunOneIteration(self, _arg)

    def GetRunOneIteration(self):
        r"""GetRunOneIteration(self) -> bool"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_GetRunOneIteration(self)

    def RunOneIterationOn(self):
        r"""RunOneIterationOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_RunOneIterationOn(self)

    def RunOneIterationOff(self):
        r"""RunOneIterationOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_RunOneIterationOff(self)

    def GetNumberOfIterationsUsed(self):
        r"""GetNumberOfIterationsUsed(self) -> unsigned long"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_GetNumberOfIterationsUsed(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_FullyConnectedOff(self)
    SameDimensionCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_SameDimensionCheck
    
    InputComparableCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_InputComparableCheck
    
    InputConvertibleToOutputCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_InputConvertibleToOutputCheck
    
    __swig_destroy__ = _itkGrayscaleGeodesicErodeImageFilterPython.delete_itkGrayscaleGeodesicErodeImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleGeodesicErodeImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleGeodesicErodeImageFilterIUC2IUC2

        Create a new object of the class itkGrayscaleGeodesicErodeImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleGeodesicErodeImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleGeodesicErodeImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleGeodesicErodeImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleGeodesicErodeImageFilterIUC2IUC2 in _itkGrayscaleGeodesicErodeImageFilterPython:
_itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC2IUC2_swigregister(itkGrayscaleGeodesicErodeImageFilterIUC2IUC2)

def itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_New():
    return itkGrayscaleGeodesicErodeImageFilterIUC3IUC3.New()

class itkGrayscaleGeodesicErodeImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkGrayscaleGeodesicErodeImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_Pointer"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_Clone(self)

    def SetMarkerImage(self, arg0):
        r"""
        SetMarkerImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC3 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_SetMarkerImage(self, arg0)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC3"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_GetMarkerImage(self)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC3 const *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_GetMaskImage(self)

    def SetRunOneIteration(self, _arg):
        r"""
        SetRunOneIteration(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_SetRunOneIteration(self, _arg)

    def GetRunOneIteration(self):
        r"""GetRunOneIteration(self) -> bool"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_GetRunOneIteration(self)

    def RunOneIterationOn(self):
        r"""RunOneIterationOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_RunOneIterationOn(self)

    def RunOneIterationOff(self):
        r"""RunOneIterationOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_RunOneIterationOff(self)

    def GetNumberOfIterationsUsed(self):
        r"""GetNumberOfIterationsUsed(self) -> unsigned long"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_GetNumberOfIterationsUsed(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_FullyConnectedOff(self)
    SameDimensionCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_SameDimensionCheck
    
    InputComparableCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_InputComparableCheck
    
    InputConvertibleToOutputCheck = _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_InputConvertibleToOutputCheck
    
    __swig_destroy__ = _itkGrayscaleGeodesicErodeImageFilterPython.delete_itkGrayscaleGeodesicErodeImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleGeodesicErodeImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleGeodesicErodeImageFilterIUC3IUC3

        Create a new object of the class itkGrayscaleGeodesicErodeImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleGeodesicErodeImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleGeodesicErodeImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleGeodesicErodeImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleGeodesicErodeImageFilterIUC3IUC3 in _itkGrayscaleGeodesicErodeImageFilterPython:
_itkGrayscaleGeodesicErodeImageFilterPython.itkGrayscaleGeodesicErodeImageFilterIUC3IUC3_swigregister(itkGrayscaleGeodesicErodeImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def grayscale_geodesic_erode_image_filter(*args: itkt.ImageLike,  marker_image: itkt.Image=..., mask_image: itkt.Image=..., run_one_iteration: bool=..., fully_connected: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for GrayscaleGeodesicErodeImageFilter"""
    import itk

    kwarg_typehints = { 'marker_image':marker_image,'mask_image':mask_image,'run_one_iteration':run_one_iteration,'fully_connected':fully_connected }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.GrayscaleGeodesicErodeImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def grayscale_geodesic_erode_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMathematicalMorphology.GrayscaleGeodesicErodeImageFilter
    grayscale_geodesic_erode_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    grayscale_geodesic_erode_image_filter.__doc__ = filter_object.__doc__



